import { React, useState, useRef } from 'react'
// .就是当前路径
import CustomNav from '@/components/CustomNav'
import Taro from '@tarojs/taro'
import { View } from '@tarojs/components';
import { getResourceList } from '@/services/home'
import MasonryLayout from '@/components/MasonryLayout';
import NoData from '@/components/NoData'
import List from '@/components/List';
import withLayout from '@/layouts'
import './searchResult.less'
import Card from '../index/components/Card'
import iconsearch from '../../assets/icons/housemantj/search.png'


const listStyle = { height: '100%' }

export default withLayout((props) => {
  const { router, person, location } = props
  const { q } = props.router.params

  const [listData, setListData] = useState({ list: [], rfTimes: 0 })

  // 横向tab
  const [queryParams, setQueryParams] = useState({ q: q, location, pageNum: 1, pageSize: 10, typeId: '' })
  const rfTimes = useRef(0)


  const listRef = useRef()



  const handleDataChange = (value, e) => {
    if (e.paramsChanged) {
      rfTimes.current += 1
      //如果context有的话代表他滚动了   那么切换tab页就置顶
      if (listRef.current?.context) {
        listRef.current.context.scrollTo({ top: 0 })
      }
    }
    setListData({ list: value, rfTimes: rfTimes.current })
  }

  const onSearch = () => {
    // 用绝对路径
    Taro.navigateTo({ url: '/pages/search/search' });
  }

  return (
    <view className='page-index'>
      <view className='index-navbar'>
        <CustomNav title='搜索' />
      </view>
      <view className='index-container' style={{ display: 'flex', flexDirection: 'column' }}>
        <view className='search'>
          <input className='searchInput' placeholder='搜索景点/店铺' disabled onClick={onSearch} />
          <image className='searchicon' src={iconsearch} />
          <view className='lineSearch'></view>
        </view>

        <View style={{ flex: 1, overflow: 'hidden' }}>
          <List
            ref={listRef}
            style={listStyle}
            request={getResourceList}
            params={queryParams}
            refresherEnabled={false}
            onDataChange={handleDataChange}
            noData={<NoData />}
          >
            <view style={{ padding: '30rpx 15rpx' }}>
              <MasonryLayout
                itemKey='resourceNo'
                listData={listData}
                render={(item) => <Card key={item.resourceNo} item={item} />}
              />
            </view>
          </List>
        </View>
      </view>
    </view>
  )
})